@@ -95,7 +95,7 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
     df['Industry'] = df['Industry'].map(industry_dictionary)
     logging.info( df['Industry'].value_counts() )
 
-    df['State'] = df['State'].map( state_dictionary )
+    df['State'] = df['State'].map( state_dictionary ).astype('float32')
     logging.info( df['State'].value_counts() )
 
     df = devutils.clean_mxtype_using_dictionary( df=df, mx_bv_dict=mx_bv_dictionary,
