@@ -542,6 +542,11 @@ def create_class_dictionaries(df_original,class_to_use:str):
     logger.info(f'Creating dictionaries for {class_to_use}')
     df=df_original[[class_to_use, 'BV', 'IDEmailStatus']].copy()
     df['BV']=df['BV'].fillna(0)
+    df.loc[(df['IDEmailStatus'] != 14) &
+             (df['IDEmailStatus'] != 31), 'IDEmailStatus'] = 0
+    df.loc[df['IDEmailStatus'] == 14, 'IDEmailStatus'] = 1
+    df.loc[df['IDEmailStatus'] == 31, 'IDEmailStatus'] = 1
+
     logger.info(f"{df['BV'].value_counts(dropna=False)}")
     groupby = df.groupby(class_to_use).agg(BV=('BV', 'mean'),
                                            Conversions=('IDEmailStatus', 'mean')
@@ -556,6 +561,27 @@ def create_class_dictionaries(df_original,class_to_use:str):
         bv_dict[f'{element[class_to_use]}'] = element['BV']
     return conversion_dict,bv_dict
 
+def clean_mxtype_using_dictionary(df,mx_bv_dict,mx_prob_dict):
+    """
+
+    :param df: Input Dataset
+    :param mx_bv_dict: MXTypes dictionary by bv performance
+    :param mx_prob_dict: MXTypes dictionary by prob performance
+    :return df: processed Dataset
+    """
+
+    if 'MXType' not in df.columns:
+        raise Exception ("MXType column not preset ( Check Caps)")
+    logger.info('Defining MXTypes')
+    df['mx_bv'] = df['MXType']
+    df = df.replace({'mx_bv': mx_bv_dict})
+    logger.info(f'{df.mx_bv.value_counts()}')
+    df['mx_prob'] = df['MXType']
+    df = df.replace( {'mx_prob': mx_prob_dict} )
+    logger.info(f'{df.mx_prob.value_counts()}')
+    return df
+
+
 def map_conv_prob_using_dictionary(df, bv_dict, prob_dict, column:str):
     """
 
